<?php
namespace OrganizationsManagement\Service;

use \Doctrine\ORM\EntityManager;
use OrganizationsManagement\Util\Utilities;
use Teknisa\Libs\Util\Environment as TeknisaEnvironment;

class DeployReport {

    /** @var EntityManager $entityManager */
    private $entityManager;
    /** @var \Teknisa\Model\Teknisa\Repositories\OmProduto $productRepository */
    private $productRepository;
    /** @var TeknisaEnvironment $environment */
    private $environment;

    public function __construct(EntityManager $entityManager, TeknisaEnvironment $environment){
        $this->entityManager = $entityManager;
        $this->environment   = $environment;
        $this->productRepository = $this->entityManager->getRepository(Utilities::TEKNISA_ENTITY_DIR . 'OmProduto');
    }

    public function getDeploys($filters = array(), $page = 0, $pageSize = 0){
        $conditions = Utilities::createQueryFiltered($filters);
        $limit  = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        return $this->productRepository->getDeploys($conditions, $limit, $offset);
    }

    public function getResources($filters = array(), $page = 0, $pageSize = 0){
        $conditions = Utilities::createQueryFiltered($filters);
        $limit  = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        return $this->productRepository->getResources($conditions, $limit, $offset);
    }

    public function getProducts($filters = array(), $page = 0, $pageSize = 0){
        $conditions = Utilities::createQueryFiltered($filters);
        $limit  = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        return $this->productRepository->getProducts($conditions, $limit, $offset);
    }

    public function getServers($filters = array(), $page = 0, $pageSize = 0){
        $conditions = Utilities::createQueryFiltered($filters);
        $limit  = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        return $this->productRepository->getServers($conditions, $limit, $offset);
    }
    
    public function getParcNegocio($filters = array(), $page = 0, $pageSize = 0){
        $conditions = Utilities::createQueryFiltered($filters);
        $limit  = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        return $this->productRepository->getParcNegocio($conditions, $limit, $offset, $this->environment->getCurrentOrganizationId());
    }
    
    public function getNatuCont(){
        return $this->productRepository->getNatuCont($this->environment->getCurrentUserId(),$this->environment->getCurrentOrganizationId());
    }

    public function getClassificacaoCaso($filter){
        $filter = Utilities::createQueryFiltered($filter);
        return $this->productRepository->getClassificacaoCaso($this->environment->getCurrentOrganizationId(),$filter);
    }

    public function getServicoProdutoReferencia($filter,$cdNatucont,$nrClassificacaocaso){
        $filter = Utilities::createQueryFiltered($filter);
        return $this->productRepository->getServicoProdutoReferencia($cdNatucont,$nrClassificacaocaso,$filter);
    }
    
    public function getMoticont($filter,$cdProduto){
        $filter = Utilities::createQueryFiltered($filter);
        return $this->productRepository->getMoticont($filter,$cdProduto);
    }
}